@@ -14,9 +14,8 @@
 # You should have received a copy of the Artistic License along with this
 # program.  If not, see <http://www.perlfoundation.org/artistic_license_2_0>.
 #
-package Graphics::Fig::Matrix;
-our $VERSION = 'v1.0.3';
-
+use 5.014;
+package Graphics::Fig::Matrix v1.0.1;
 use strict;
 use warnings;
 use Carp;
