@@ -14,14 +14,14 @@
 # You should have received a copy of the Artistic License along with this
 # program.  If not, see <http://www.perlfoundation.org/artistic_license_2_0>.
 #
-package Graphics::Fig::Text;
-our $VERSION = 'v1.0.3';
-
+use 5.014;
+package Graphics::Fig::Text v1.0.1;
 use strict;
 use warnings;
 use Carp;
 use Math::Trig;
 use Image::Info qw(image_info);
+use Regexp::Common qw (number);
 use Graphics::Fig::Color;
 use Graphics::Fig::Parameters;
 
